@@ -1,10 +1,12 @@
-#!/bin/env perl 
+#!perl -w
 #!d:\perl\bin\perl.exe 
 
+# -- SOAP::Lite -- soaplite.com -- Copyright (C) 2001 Paul Kulchenko --
+
 use SOAP::Lite;
 
 SOAP::Lite
-  -> uri('http://soaplite.com/My/Examples')                
+  -> uri('http://www.soaplite.com/My/Examples')                
   -> proxy('mailto:destination.email@address', smtp => 'smtp.server', From => 'your.email', Subject => 'SOAP message')
 
   # or 
