@@ -4,7 +4,7 @@
 # SOAP::Lite is free software; you can redistribute it
 # and/or modify it under the same terms as Perl itself.
 #
-# $Id: Packager.pm 372 2010-04-29 18:32:31Z kutterma $
+# $Id: Packager.pm 384 2011-08-16 17:08:08Z kutterma $
 #
 # ======================================================================
 
@@ -13,7 +13,7 @@ package SOAP::Packager;
 use strict;
 use vars;
 
-our $VERSION = 0.712;
+our $VERSION = 0.713;
 our $SUPPORTED_TYPES = { };
 
 sub BEGIN {
@@ -199,7 +199,7 @@ sub process_form_data {
     my $name = $part->head->mime_attr('content-disposition.name');
     $name eq 'payload' ?
       $env = $part->bodyhandle->as_string
-	: $self->push_part($part);
+      : $self->push_part($part);
   }
   return $env;
 }
@@ -244,7 +244,7 @@ sub process_related {
     # alternative in the following MIME Header attributes
     my $plocation = $part->head->get('content-location') ||
       $part->head->mime_attr('Content-Disposition.filename') ||
-	$part->head->mime_attr('Content-Type.name');
+      $part->head->mime_attr('Content-Type.name');
     if ($start && $pid eq $start) {
       $env = $part->bodyhandle->as_string;
     } else {
@@ -304,7 +304,7 @@ sub package {
    my $soapversion = defined($context) ? $context->soapversion : '1.1';
    $top->attach('MIMEType' => $soapversion == 1.1 ?
                   "http://schemas.xmlsoap.org/soap/envelope/" : "application/soap+xml",
-                'Data'     => $envelope );
+                'Data'     => \$envelope );
    $message->add_payload($top);
    # consume the attachments that come in as input by 'shift'ing
    no strict 'refs';
