@@ -4,7 +4,7 @@
 # SOAP::Lite is free software; you can redistribute it
 # and/or modify it under the same terms as Perl itself.
 #
-# $Id: HTTP.pm 374 2010-05-14 08:12:25Z kutterma $
+# $Id: HTTP.pm 384 2011-08-16 17:08:08Z kutterma $
 #
 # ======================================================================
 
@@ -12,7 +12,7 @@ package SOAP::Transport::HTTP;
 
 use strict;
 
-our $VERSION = 0.712;
+our $VERSION = 0.713;
 
 use SOAP::Lite;
 use SOAP::Packager;
@@ -197,13 +197,13 @@ sub send_receive {
           # from string (doing pack with 'C0A*' modifier) if length and
           # bytelength are not the same
             my $bytelength = SOAP::Utils::bytelength($envelope);
-			if ($] < 5.008) {
-				$envelope = pack( 'C0A*', $envelope );
-			}
-			else {
-				require Encode;
-				$envelope = Encode::encode('UTF-8', $envelope); 
-			}
+            if ($] < 5.008) {
+                $envelope = pack( 'C0A*', $envelope );
+            }
+            else {
+                require Encode;
+                $envelope = Encode::encode('UTF-8', $envelope);
+            }
             #  if !$SOAP::Constants::DO_NOT_USE_LWP_LENGTH_HACK
             #      && length($envelope) != $bytelength;
             $http_request->content($envelope);
@@ -566,9 +566,16 @@ sub handle {
         if ( !$chunked ) {
             my $buffer;
             binmode(STDIN);
-            while ( sysread( STDIN, $buffer, $length ) ) {
-                $content .= $buffer;
-                last if ( length($content) >= $length );
+            if ( defined $ENV{'MOD_PERL'} ) {
+                while ( read( STDIN, $buffer, $length ) ) {
+                    $content .= $buffer;
+                    last if ( length($content) >= $length );
+                }
+            } else {
+                while ( sysread( STDIN, $buffer, $length ) ) {
+                    $content .= $buffer;
+                    last if ( length($content) >= $length );
+                }
             }
         }
 
